@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketPrint.pm - to get a closer view
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketPrint.pm,v 1.32 2006/10/02 12:55:02 mh Exp $
+# $Id: AgentTicketPrint.pm,v 1.32.2.5 2007/07/26 15:37:44 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -17,7 +17,7 @@ use Kernel::System::LinkObject;
 use Kernel::System::PDF;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.32 $';
+$VERSION = '$Revision: 1.32.2.5 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -164,6 +164,7 @@ sub Run {
         # create new pdf document
         $Self->{PDFObject}->DocumentNew(
             Title => $Self->{ConfigObject}->Get('Product') . ': ' . $Title,
+            Encode => $Self->{LayoutObject}->{Charset},
         );
         # create first pdf page
         $Self->{PDFObject}->PageNew(
@@ -278,60 +279,60 @@ sub _PDFOutputTicketInfos {
     my %Page = %{$Param{PageData}};
     my %TableParam;
     $TableParam{CellData}[0][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('State') . ':';
-    $TableParam{CellData}[0][0]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[0][0]{Font} = 'ProportionalBold';
     $TableParam{CellData}[0][1]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get($Ticket{State});
     $TableParam{CellData}[0][2]{Content} = ' ';
     $TableParam{CellData}[0][2]{BackgroundColor} = '#FFFFFF';
     $TableParam{CellData}[0][3]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Age') . ':';
-    $TableParam{CellData}[0][3]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[0][3]{Font} = 'ProportionalBold';
     $TableParam{CellData}[0][4]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get($Ticket{Age});
 
     $TableParam{CellData}[1][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Priority') . ':';
-    $TableParam{CellData}[1][0]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[1][0]{Font} = 'ProportionalBold';
     $TableParam{CellData}[1][1]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get($Ticket{Priority});
     $TableParam{CellData}[1][2]{Content} = ' ';
     $TableParam{CellData}[1][2]{BackgroundColor} = '#FFFFFF';
     $TableParam{CellData}[1][3]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Created') . ':';
-    $TableParam{CellData}[1][3]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[1][3]{Font} = 'ProportionalBold';
     $TableParam{CellData}[1][4]{Content} =
         $Self->{LayoutObject}->Output(
             Template => '$TimeLong{"$Data{"Created"}"}',
             Data => \%Ticket,
         );
     $TableParam{CellData}[2][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Queue') . ':';
-    $TableParam{CellData}[2][0]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[2][0]{Font} = 'ProportionalBold';
     $TableParam{CellData}[2][1]{Content} = $Ticket{Queue};
     $TableParam{CellData}[2][2]{Content} = ' ';
     $TableParam{CellData}[2][2]{BackgroundColor} = '#FFFFFF';
     $TableParam{CellData}[2][3]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Accounted time') . ':';
-    $TableParam{CellData}[2][3]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[2][3]{Font} = 'ProportionalBold';
     $TableParam{CellData}[2][4]{Content} = $Ticket{TicketTimeUnits};
 
     $TableParam{CellData}[3][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Lock') . ':';
-    $TableParam{CellData}[3][0]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[3][0]{Font} = 'ProportionalBold';
     $TableParam{CellData}[3][1]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get($Ticket{Lock});
     $TableParam{CellData}[3][2]{Content} = ' ';
     $TableParam{CellData}[3][2]{BackgroundColor} = '#FFFFFF';
     $TableParam{CellData}[3][3]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Escalation in') . ':';
-    $TableParam{CellData}[3][3]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[3][3]{Font} = 'ProportionalBold';
     $TableParam{CellData}[3][4]{Content} = $Ticket{TicketOverTime};
 
     $TableParam{CellData}[4][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('CustomerID') . ':';
-    $TableParam{CellData}[4][0]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[4][0]{Font} = 'ProportionalBold';
     $TableParam{CellData}[4][1]{Content} = $Ticket{CustomerID};
     $TableParam{CellData}[4][2]{Content} = ' ';
     $TableParam{CellData}[4][2]{BackgroundColor} = '#FFFFFF';
     $TableParam{CellData}[4][3]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Pending till') . ':';
-    $TableParam{CellData}[4][3]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[4][3]{Font} = 'ProportionalBold';
     $TableParam{CellData}[4][4]{Content} = $Ticket{PendingUntil};
 
     $TableParam{CellData}[5][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Owner') . ':';
-    $TableParam{CellData}[5][0]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[5][0]{Font} = 'ProportionalBold';
     $TableParam{CellData}[5][1]{Content} = $Ticket{Owner} . ' (' . $UserInfo{UserFirstname} . ' ' . $UserInfo{UserLastname} . ')';
     $TableParam{CellData}[5][2]{Content} = ' ';
     $TableParam{CellData}[5][2]{BackgroundColor} = '#FFFFFF';
     $TableParam{CellData}[5][3]{Content} = ' ';
-    $TableParam{CellData}[5][3]{Font} = 'HelveticaBold';
+    $TableParam{CellData}[5][3]{Font} = 'ProportionalBold';
     $TableParam{CellData}[5][4]{Content} = ' ';
 
     $TableParam{ColumnData}[0]{Width} = 80;
@@ -409,21 +410,21 @@ sub _PDFOutputLinkedObjects {
         if ($LONormal) {
             $TableParam{CellData}[$Row][0]{Content} =
                 $Self->{LayoutObject}->{LanguageObject}->Get('Normal') . ':';
-            $TableParam{CellData}[$Row][0]{Font} = 'HelveticaBold';
+            $TableParam{CellData}[$Row][0]{Font} = 'ProportionalBold';
             $TableParam{CellData}[$Row][1]{Content} = $LONormal;
             $Row++;
         }
         if ($LOParent) {
             $TableParam{CellData}[$Row][0]{Content} =
                 $Self->{LayoutObject}->{LanguageObject}->Get('Parent') . ':';
-            $TableParam{CellData}[$Row][0]{Font} = 'HelveticaBold';
+            $TableParam{CellData}[$Row][0]{Font} = 'ProportionalBold';
             $TableParam{CellData}[$Row][1]{Content} = $LOParent;
             $Row++;
         }
         if ($LOChild) {
             $TableParam{CellData}[$Row][0]{Content} =
                 $Self->{LayoutObject}->{LanguageObject}->Get('Child') . ':';
-            $TableParam{CellData}[$Row][0]{Font} = 'HelveticaBold';
+            $TableParam{CellData}[$Row][0]{Font} = 'ProportionalBold';
             $TableParam{CellData}[$Row][1]{Content} = $LOChild;
             $Row++;
         }
@@ -440,7 +441,7 @@ sub _PDFOutputLinkedObjects {
             Text => $Self->{LayoutObject}->{LanguageObject}->Get('Linked Objects'),
             Height => 7,
             Type => 'Cut',
-            Font => 'HelveticaBoldItalic',
+            Font => 'ProportionalBoldItalic',
             FontSize => 7,
             Color => '#666666',
         );
@@ -499,7 +500,7 @@ sub _PDFOutputTicketFreeText {
     foreach (1..16) {
         if ($Ticket{"TicketFreeText$_"} ne "") {
             $TableParam{CellData}[$Row][0]{Content} = $Ticket{"TicketFreeKey$_"} . ':';
-            $TableParam{CellData}[$Row][0]{Font} = 'HelveticaBold';
+            $TableParam{CellData}[$Row][0]{Font} = 'ProportionalBold';
             $TableParam{CellData}[$Row][1]{Content} = $Ticket{"TicketFreeText$_"};
 
             $Row++;
@@ -521,7 +522,7 @@ sub _PDFOutputTicketFreeText {
             Text => $Self->{LayoutObject}->{LanguageObject}->Get('TicketFreeText'),
             Height => 7,
             Type => 'Cut',
-            Font => 'HelveticaBoldItalic',
+            Font => 'ProportionalBoldItalic',
             FontSize => 7,
             Color => '#666666',
         );
@@ -579,10 +580,18 @@ sub _PDFOutputTicketFreeTime {
     my $Row = 0;
     # generate table
     foreach (1..2) {
-        if ($Ticket{"TicketFreeTime$_"} ne "") {
-            $TableParam{CellData}[$Row][0]{Content} = $Ticket{"TicketFreeTimeKey$_"} . ':';
-            $TableParam{CellData}[$Row][0]{Font} = 'HelveticaBold';
-            $TableParam{CellData}[$Row][1]{Content} = $Ticket{"TicketFreeTime$_"};
+        if ($Ticket{"TicketFreeTime$_"}) {
+            my $TicketFreeTimeKey = $Self->{ConfigObject}->Get('TicketFreeTimeKey'.$_) || '';
+            my $TicketFreeTime = $Ticket{"TicketFreeTime$_"};
+
+            $TableParam{CellData}[$Row][0]{Content} = $TicketFreeTimeKey . ':';
+            $TableParam{CellData}[$Row][0]{Font} = 'ProportionalBold';
+            $TableParam{CellData}[$Row][1]{Content} = $Self->{LayoutObject}->Output(
+                Template => '$TimeLong{"$Data{"TicketFreeTime"}"}',
+                Data => {
+                    TicketFreeTime => $TicketFreeTime,
+                },
+            );
 
             $Row++;
             $Output = 1;
@@ -603,7 +612,7 @@ sub _PDFOutputTicketFreeTime {
             Text => $Self->{LayoutObject}->{LanguageObject}->Get('TicketFreeTime'),
             Height => 7,
             Type => 'Cut',
-            Font => 'HelveticaBoldItalic',
+            Font => 'ProportionalBoldItalic',
             FontSize => 7,
             Color => '#666666',
         );
@@ -653,6 +662,7 @@ sub _PDFOutputCustomerInfos {
             return;
         }
     }
+    my $Output = 0;
     my %CustomerData = %{$Param{CustomerData}};
     my %Page = %{$Param{PageData}};
     my %TableParam;
@@ -662,58 +672,62 @@ sub _PDFOutputCustomerInfos {
         if (${$Field}[3] && $CustomerData{${$Field}[0]}) {
             $TableParam{CellData}[$Row][0]{Content} =
                 $Self->{LayoutObject}->{LanguageObject}->Get(${$Field}[1]) . ':';
-            $TableParam{CellData}[$Row][0]{Font} = 'HelveticaBold';
+            $TableParam{CellData}[$Row][0]{Font} = 'ProportionalBold';
             $TableParam{CellData}[$Row][1]{Content} = $CustomerData{${$Field}[0]};
+
             $Row++;
+            $Output = 1;
         }
     }
     $TableParam{ColumnData}[0]{Width} = 80;
     $TableParam{ColumnData}[1]{Width} = 431;
 
-    # set new position
-    $Self->{PDFObject}->PositionSet(
-        Move => 'relativ',
-        Y => -15,
-    );
-    # output headline
-    $Self->{PDFObject}->Text(
-        Text => $Self->{LayoutObject}->{LanguageObject}->Get('Customer Infos'),
-        Height => 7,
-        Type => 'Cut',
-        Font => 'HelveticaBoldItalic',
-        FontSize => 7,
-        Color => '#666666',
-    );
-    # set new position
-    $Self->{PDFObject}->PositionSet(
-        Move => 'relativ',
-        Y => -4,
-    );
-    # table params
-    $TableParam{Type} = 'Cut';
-    $TableParam{Border} = 0;
-    $TableParam{FontSize} = 6;
-    $TableParam{BackgroundColor} = '#DDDDDD';
-    $TableParam{Padding} = 1;
-    $TableParam{PaddingTop} = 3;
-    $TableParam{PaddingBottom} = 3;
-
-    # output table
-    for ($Page{PageCount}..$Page{MaxPages}) {
-        # output table (or a fragment of it)
-        %TableParam = $Self->{PDFObject}->Table(
-            %TableParam,
+    if ($Output) {
+        # set new position
+        $Self->{PDFObject}->PositionSet(
+            Move => 'relativ',
+            Y => -15,
         );
-        # stop output or output next page
-        if ($TableParam{State}) {
-            last;
-        }
-        else {
-            $Self->{PDFObject}->PageNew(
-                %Page,
-                FooterRight => $Page{PageText} . ' ' . $Page{PageCount},
+        # output headline
+        $Self->{PDFObject}->Text(
+            Text => $Self->{LayoutObject}->{LanguageObject}->Get('Customer Infos'),
+            Height => 7,
+            Type => 'Cut',
+            Font => 'ProportionalBoldItalic',
+            FontSize => 7,
+            Color => '#666666',
+        );
+        # set new position
+        $Self->{PDFObject}->PositionSet(
+            Move => 'relativ',
+            Y => -4,
+        );
+        # table params
+        $TableParam{Type} = 'Cut';
+        $TableParam{Border} = 0;
+        $TableParam{FontSize} = 6;
+        $TableParam{BackgroundColor} = '#DDDDDD';
+        $TableParam{Padding} = 1;
+        $TableParam{PaddingTop} = 3;
+        $TableParam{PaddingBottom} = 3;
+
+        # output table
+        for ($Page{PageCount}..$Page{MaxPages}) {
+            # output table (or a fragment of it)
+            %TableParam = $Self->{PDFObject}->Table(
+                %TableParam,
             );
-            $Page{PageCount}++;
+            # stop output or output next page
+            if ($TableParam{State}) {
+                last;
+            }
+            else {
+                $Self->{PDFObject}->PageNew(
+                    %Page,
+                    FooterRight => $Page{PageText} . ' ' . $Page{PageCount},
+                );
+                $Page{PageCount}++;
+            }
         }
     }
 }
@@ -742,7 +756,7 @@ sub _PDFOutputArticles {
                 Text => $Self->{LayoutObject}->{LanguageObject}->Get('Articles'),
                 Height => 7,
                 Type => 'Cut',
-                Font => 'HelveticaBoldItalic',
+                Font => 'ProportionalBoldItalic',
                 FontSize => 7,
                 Color => '#666666',
             );
@@ -770,13 +784,13 @@ sub _PDFOutputArticles {
         foreach (qw(From To Cc Subject)) {
             if ($Article{$_}) {
                 $TableParam1{CellData}[$Row][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get($_) . ':';
-                $TableParam1{CellData}[$Row][0]{Font} = 'HelveticaBold';
+                $TableParam1{CellData}[$Row][0]{Font} = 'ProportionalBold';
                 $TableParam1{CellData}[$Row][1]{Content} = $Article{$_};
                 $Row++;
             }
         }
         $TableParam1{CellData}[$Row][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Created') . ':';
-        $TableParam1{CellData}[$Row][0]{Font} = 'HelveticaBold';
+        $TableParam1{CellData}[$Row][0]{Font} = 'ProportionalBold';
         $TableParam1{CellData}[$Row][1]{Content} =
             $Self->{LayoutObject}->Output(
                 Template => '$TimeLong{"$Data{"Created"}"}',
@@ -787,22 +801,22 @@ sub _PDFOutputArticles {
         $Row++;
 
         foreach (1..3) {
-            if ($Article{"FreeText$_"}) {
-                $TableParam1{CellData}[$Row][0]{Content} = $Article{"FreeKey$_"} . ':';
-                $TableParam1{CellData}[$Row][0]{Font} = 'HelveticaBold';
-                $TableParam1{CellData}[$Row][1]{Content} = $Article{"FreeText$_"};
+            if ($Article{"ArticleFreeText$_"}) {
+                $TableParam1{CellData}[$Row][0]{Content} = $Article{"ArticleFreeKey$_"} . ':';
+                $TableParam1{CellData}[$Row][0]{Font} = 'ProportionalBold';
+                $TableParam1{CellData}[$Row][1]{Content} = $Article{"ArticleFreeText$_"};
                 $Row++;
             }
         }
 
         $TableParam1{CellData}[$Row][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Type') . ':';
-        $TableParam1{CellData}[$Row][0]{Font} = 'HelveticaBold';
+        $TableParam1{CellData}[$Row][0]{Font} = 'ProportionalBold';
         $TableParam1{CellData}[$Row][1]{Content} = $Article{ArticleType};
         $Row++;
 
         if ($Attachments) {
             $TableParam1{CellData}[$Row][0]{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Attachment') . ':';
-            $TableParam1{CellData}[$Row][0]{Font} = 'HelveticaBold';
+            $TableParam1{CellData}[$Row][0]{Font} = 'ProportionalBold';
             chomp($Attachments);
             $TableParam1{CellData}[$Row][1]{Content} = $Attachments;
         }
@@ -847,7 +861,7 @@ sub _PDFOutputArticles {
         $TableParam2{CellData}[0][0]{Content} = $Article{Body} || ' ';
         $TableParam2{Type} = 'Cut';
         $TableParam2{Border} = 0;
-        $TableParam2{Font} = 'Courier';
+        $TableParam2{Font} = 'Monospaced';
         $TableParam2{FontSize} = 7;
         $TableParam2{BackgroundColor} = '#DDDDDD';
         $TableParam2{Padding} = 4;
@@ -908,7 +922,7 @@ sub _HTMLMask {
         else {
             # html quoting
             $Article{Body} = $Self->{LayoutObject}->Ascii2Html(
-                NewLine => $Self->{ConfigObject}->Get('DefaultViewNewLine') || 85,
+                NewLine => $Self->{ConfigObject}->Get('DefaultViewNewLine') || 90,
                 Text => $Article{Body},
                 VMax => $Self->{ConfigObject}->Get('DefaultViewLines') || 5000,
             );
@@ -955,12 +969,12 @@ sub _HTMLMask {
         }
         # show article free text
         foreach (1..3) {
-            if ($Article{"FreeText$_"}) {
+            if ($Article{"ArticleFreeText$_"}) {
                 $Self->{LayoutObject}->Block(
                     Name => 'ArticleFreeText',
                     Data => {
-                        Key => $Article{"FreeKey$_"},
-                        Value => $Article{"FreeText$_"},
+                        Key => $Article{"ArticleFreeKey$_"},
+                        Value => $Article{"ArticleFreeText$_"},
                     },
                 );
             }
