@@ -1,12 +1,12 @@
 # --
 # Kernel/System/Config.pm - all system config tool functions
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: Config.pm,v 1.57 2006/11/22 12:36:33 tr Exp $
+# $Id: Config.pm,v 1.57.2.4 2008/07/15 12:58:31 rk Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::System::Config;
@@ -18,7 +18,7 @@ use Kernel::System::Main;
 use Kernel::Config;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.57 $';
+$VERSION = '$Revision: 1.57.2.4 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -119,11 +119,65 @@ sub _Init {
                 close (IN);
             }
             else {
-                print STDERR "ERROR: $!: $File\n";
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message => "Can't open file $File: $!",
+                );
             }
+            my $FileCachePart = $File;
+            $FileCachePart =~ s/$Self->{Home}//;
+            $FileCachePart =~ s/\/\//\//g;
+            $FileCachePart =~ s/\//_/g;
             if ($ConfigFile) {
-                my @XMLHash = $Self->{XMLObject}->XMLParse2XMLHash(String => $ConfigFile);
-                $Data{$File} = \@XMLHash;
+                my $CacheFileUsed = 0;
+                use Digest::MD5 qw(md5_hex);
+                my $Digest = md5_hex($ConfigFile);
+                my $FileCache = "$Self->{Home}/var/tmp/SysConfig-Cache$FileCachePart-$Digest.pm";
+                if (-e $FileCache) {
+                    my $ConfigFileCache = '';
+                    if (open (IN, "< $FileCache")) {
+                        while (<IN>) {
+                            $ConfigFileCache .= $_;
+                        }
+                        close (IN);
+                        my $XMLHashRef;
+                        if (eval $ConfigFileCache) {
+                            $Data{$File} = $XMLHashRef;
+                            $CacheFileUsed = 1;
+                        }
+                    }
+                    else {
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message => "Can't open cache file $FileCache: $!",
+                        );
+                    }
+
+                }
+                else {
+                    # remove all cache files
+                    my @List = glob("$Self->{Home}/var/tmp/SysConfig-Cache$FileCachePart-*.pm");
+                    foreach my $File (@List) {
+                        unlink $File;
+                    }
+                }
+                # parse config files
+                if (!$CacheFileUsed) {
+                    my @XMLHash = $Self->{XMLObject}->XMLParse2XMLHash(String => $ConfigFile);
+                    $Data{$File} = \@XMLHash;
+                    my $Dump = Data::Dumper::Dumper(\@XMLHash);
+                    $Dump =~ s/\$VAR1/\$XMLHashRef/;
+                    if (open (OUT, "> $FileCache")) {
+                        print OUT $Dump."\n1;";
+                        close (OUT);
+                    }
+                    else {
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message => "Can't write cache file $FileCache: $!",
+                        );
+                    }
+                }
             }
         }
         $Self->{XMLConfig} = [];
@@ -222,8 +276,11 @@ sub Download {
             return;
         }
     }
-    if (!open(IN, "< $Home/Kernel/Config/Files/ZZZAuto.pm")) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Can't open $Home/Kernel/Config/Files/ZZZAuto.pm!");
+    if (! -e "$Home/Kernel/Config/Files/ZZZAuto.pm") {
+        return $File;
+    }
+    elsif (!open(IN, "< $Home/Kernel/Config/Files/ZZZAuto.pm")) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Can't open $Home/Kernel/Config/Files/ZZZAuto.pm: $!");
         return '';
     }
     else {
@@ -1263,7 +1320,7 @@ sub _XML2Perl {
                     foreach my $Index (1...$#{$Param{Data}->{Setting}->[1]->{FrontendModuleReg}->[1]->{$Key}}) {
                         my $Content = $Param{Data}->{Setting}->[1]->{FrontendModuleReg}->[1]->{$Key}->[$Index];
                         my %NavBar = ();
-                        foreach $Key (sort keys %{$Content}) {
+                        foreach my $Key (sort keys %{$Content}) {
                             if ($Key eq 'Group' || $Key eq 'GroupRo') {
                                 my @Array = ();
                                 foreach my $Index (1...$#{$Content->{$Key}}) {
@@ -1288,7 +1345,7 @@ sub _XML2Perl {
                 else {
                     my $Content = $Param{Data}->{Setting}->[1]->{FrontendModuleReg}->[1]->{$Key};
                     my %NavBar = ();
-                    foreach $Key (sort keys %{$Content}) {
+                    foreach my $Key (sort keys %{$Content}) {
                         if ($Key eq 'Group' || $Key eq 'GroupRo') {
                             my @Array = ();
                             foreach my $Index (1...$#{$Content->{$Key}}) {
@@ -1377,12 +1434,12 @@ This software is part of the OTRS project (http://otrs.org/).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.57 $ $Date: 2006/11/22 12:36:33 $
+$Revision: 1.57.2.4 $ $Date: 2008/07/15 12:58:31 $
 
 =cut
