@@ -2,7 +2,7 @@
 # Kernel/System/Ticket/Article.pm - global article module for OTRS kernel
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Article.pm,v 1.128.2.1 2007/01/09 02:36:00 martin Exp $
+# $Id: Article.pm,v 1.128.2.4 2007/03/02 01:19:21 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -18,7 +18,7 @@ use Mail::Internet;
 use Kernel::System::StdAttachment;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.128.2.1 $';
+$VERSION = '$Revision: 1.128.2.4 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -215,6 +215,11 @@ sub ArticleCreate {
                 TicketID => $Param{TicketID},
                 UserID => $Param{UserID},
            );
+            $Self->TicketUnlockTimeoutUpdate(
+                 UnlockTimeout => $Self->{TimeObject}->SystemTime(),
+                 TicketID => $Param{TicketID},
+                 UserID => $Param{UserID},
+            );
         }
     }
     elsif ($Param{SenderType} eq 'agent' && $Param{ArticleType} =~ /email-ext|phone|fax|sms|note-ext/) {
@@ -224,6 +229,11 @@ sub ArticleCreate {
             TicketID => $Param{TicketID},
             UserID => $Param{UserID},
         );
+        $Self->TicketUnlockTimeoutUpdate(
+             UnlockTimeout => $Self->{TimeObject}->SystemTime(),
+             TicketID => $Param{TicketID},
+             UserID => $Param{UserID},
+        );
     }
     # send auto response
     my %Ticket = $Self->TicketGet(TicketID => $Param{TicketID});
@@ -508,7 +518,7 @@ sub _ArticleGetId {
     if ($Param{Subject}) {
         $SQL .= "a_subject = '$Param{Subject}' AND ";
     }
-    $SQL .= " incoming_time = '$Param{IncomingTime}'";
+    $SQL .= " incoming_time = $Param{IncomingTime}";
     # start query
     $Self->{DBObject}->Prepare(SQL => $SQL);
     my $Id;
@@ -2617,7 +2627,7 @@ write an article attachemnt to storage
 
 get article attachment index as hash (ID => hashref (Filename, Filesize))
 
-  my %Index = $TicketObject->ArticleAttachment(
+  my %Index = $TicketObject->ArticleAttachmentIndex(
       ArticleID => 123,
       UserID => 123,
   );
